Pass -Wall,no-obsolete to autoreconf.

diff --git a/autogen.sh b/autogen.sh
index 9650eb7..efa5a59 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -15,8 +15,8 @@
 
 set -ex
 
-# TODO(kenton):  Use -Wall and fix the resulting warnings.
-autoreconf -f -i
+# TODO(kenton):  Remove the ",no-obsolete" part and fix the resulting warnings.
+autoreconf -f -i -Wall,no-obsolete
 
 rm -rf autom4te.cache config.h.in~
 exit 0